[Top][All Lists]
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Emacs-diffs] Changes to emacs/src/w32font.c,v
From: |
Jason Rumney |
Subject: |
[Emacs-diffs] Changes to emacs/src/w32font.c,v |
Date: |
Fri, 25 Jul 2008 00:36:48 +0000 |
CVSROOT: /sources/emacs
Module name: emacs
Changes by: Jason Rumney <jasonr> 08/07/25 00:36:45
Index: w32font.c
===================================================================
RCS file: /sources/emacs/emacs/src/w32font.c,v
retrieving revision 1.48
retrieving revision 1.49
diff -u -b -r1.48 -r1.49
--- w32font.c 23 Jul 2008 15:37:44 -0000 1.48
+++ w32font.c 25 Jul 2008 00:36:45 -0000 1.49
@@ -2328,10 +2328,10 @@
Return fontconfig style font string corresponding to the selection.
If FRAME is omitted or nil, it defaults to the selected frame.
-If INCLUDE-PROPORTIONAL is non-nil, include proportional fonts
+If EXCLUDE-PROPORTIONAL is non-nil, exclude proportional fonts
in the font selection dialog. */)
- (frame, include_proportional)
- Lisp_Object frame, include_proportional;
+ (frame, exclude_proportional)
+ Lisp_Object frame, exclude_proportional;
{
FRAME_PTR f = check_x_frame (frame);
CHOOSEFONT cf;
@@ -2348,9 +2348,9 @@
cf.hwndOwner = FRAME_W32_WINDOW (f);
cf.Flags = CF_FORCEFONTEXIST | CF_SCREENFONTS | CF_NOVERTFONTS;
/* Unless include_proportional is non-nil, limit the selection to
monospaced fonts. */
- if (NILP (include_proportional))
+ if (!NILP (exclude_proportional))
cf.Flags |= CF_FIXEDPITCHONLY;
cf.lpLogFont = &lf;
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/01
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Kenichi Handa, 2008/07/08
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/23
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/23
- [Emacs-diffs] Changes to emacs/src/w32font.c,v,
Jason Rumney <=
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/25
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/25
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/28
- [Emacs-diffs] Changes to emacs/src/w32font.c,v, Jason Rumney, 2008/07/30
@@ -2348,9 +2348,9 @@
cf.hwndOwner = FRAME_W32_WINDOW (f);
cf.Flags = CF_FORCEFONTEXIST | CF_SCREENFONTS | CF_NOVERTFONTS;
- /* Unless include_proportional is non-nil, limit the selection to
+ /* If exclude_proportional is non-nil, limit the selection to
monospaced fonts. */